@@ -66,7 +66,7 @@ class VivadoEmulation(VivadoTCLGenerator):
             constrs.writeln('create_generated_clock -name emu_clk -source [get_pins clk_gen_i/clk_wiz_0_i/clk_out1] -divide_by 2 [get_pins gen_emu_clks_i/buf_emu_clk/I]')
 
             for k in range(scfg.num_gated_clks):
-                constrs.writeln(f'create_generated_clock -name clk_other_{k} -source [get_pins clk_gen_i/clk_wiz_0_i/clk_out1] -divide_by 4 [get_pins gen_emu_clks_i/gen_other[{k}].buf_i/I]')
+                constrs.writeln(f'create_generated_clock -name clk_other_{k} -source [get_pins clk_gen_i/clk_wiz_0_i/clk_out1] -divide_by 4 [get_pins gen_emu_clks_i/buf_{k}/I]')
 
             # Setup ILA for signal probing - only of at least one probe is defined
             if len(scfg.analog_probes + scfg.digital_probes + [scfg.time_probe]) != 0:
